package MyClientTests;

import static org.junit.Assert.*;

import java.util.ArrayList;
import java.util.List;

import static org.easymock.EasyMock.expect;

import org.junit.Test;
import org.junit.runner.RunWith;
import org.powermock.api.easymock.PowerMock;
import org.powermock.core.classloader.annotations.PrepareForTest;
import org.powermock.modules.junit4.PowerMockRunner;

import MyClient.Client;
import VmManager.Manager;
import VmManager.VM;

@RunWith(PowerMockRunner.class)
@PrepareForTest({Manager.class, VM.class})
public class ClientTestsPowerMock
{
    @Test
    public void testGetVMNames()
    {
        // Arrange
        VM vm = PowerMock.createMock(VM.class);
        expect(vm.getName()).andReturn("vm1");
        
        Manager manager = PowerMock.createMock(Manager.class);
        List<VM> vmList = new ArrayList<VM>();
        vmList.add(vm);
        expect(manager.getVMs()).andReturn(vmList);
        
        PowerMock.replay(manager);
        PowerMock.replay(vm);
        
        Client client = new Client(manager);

        // Act
        List<String> names = client.getVMNames();

        // Assert
        assertEquals(1, names.size());
        assertEquals("vm1", names.get(0));

        PowerMock.verify(manager);
        PowerMock.verify(vm);
    }

    @Test
    public void TestVerifyManagerTooOld()
    {
        // Arrange
        PowerMock.mockStatic(Manager.class);
        expect(Manager.getVersion()).andReturn(13);
        
        PowerMock.replay(Manager.class);
        
        // Act
        Boolean result = Client.verifyManager();
        
        // Assert
        assertFalse(result);

        PowerMock.verify(Manager.class);
    }
}
